==> claromentis-framework-8.13.65-b8aa1bfb.zip: web/intranet/core/classes/Acl/RoleBased/RoleAclChecker.php <==
<?php
namespace Claromentis\Core\Acl\RoleBased;

$GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab7848e53" . "6215"] ?: array()) + array("i" . "d" => base64_decode("aWQ" . "="), "_bd71c3b5c2" . "01fc11db82e" . "d14ce424de5" => base64_decode("aW5fYXJyYXk" . "="), "right" . "s" => base64_decode("cmln" . "aHRz"), "_31767d7ad58e706dbf4" . "7b7a51a0fe6c4" => base64_decode("Y291b" . "nQ="));
class RoleAclChecker
{
    protected $role_repository;
    public function __construct(RoleRepository $_90f6cb30a269a622b4c838bfd5a0a5db)
    {
        $this->role_repository = $_90f6cb30a269a622b4c838bfd5a0a5db;
    }
    
    
    
    
    
    
    
    
    
    
    public function GetUsersWithRight(int $aggregation, int $object_id, int $_18f48e103c59a05cbe75b66b44ec5728) : array
    {
        $_25fb31f00b26bde87effd4759e283d9f = $this->GetRolesWithRight($aggregation, $object_id, $_18f48e103c59a05cbe75b66b44ec5728);
        if ($GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"]["_31767d7ad58e706dbf47b" . "7a51a0fe6c4"]($_25fb31f00b26bde87effd4759e283d9f) === 0) {
            return [];
        }
        $_23ab4dd81b6c619f47099ef7c2485a12 = $this->role_repository->GetRoles($aggregation, $object_id);
        $_8c6037710e6dfed74748240d3b8181f3 = [];
        foreach ($_23ab4dd81b6c619f47099ef7c2485a12 as $_d1071a032215f0eb5c4a8ef175f7049d) {
            if ($GLOBALS["__65da1b1ec2" . "d6653e8a0ab7" . "848e536215"]["_bd71c3b5c2" . "01fc11db82e" . "d14ce424de5"]($_d1071a032215f0eb5c4a8ef175f7049d[$GLOBALS["__65da1b1ec2d6653e8a0ab7" . "848e536215"]["i" . "d"]], $_25fb31f00b26bde87effd4759e283d9f)) {
                $_8c6037710e6dfed74748240d3b8181f3[] = $_d1071a032215f0eb5c4a8ef175f7049d;
            }
        }
        $_99a8277755f8f533f3f5f339fcc8b45e = $this->MergeRolePerms($_8c6037710e6dfed74748240d3b8181f3);
        return $_99a8277755f8f533f3f5f339fcc8b45e->GetIndividualsList(PERM_VIEW);
    }
    
    
    
    
    
    
    
    
    
    
    public function GetRolesWithRight(int $aggregation, int $object_id, int $_18f48e103c59a05cbe75b66b44ec5728) : array
    {
        return $this->role_repository->GetAllRolesWithRight($aggregation, $object_id, $_18f48e103c59a05cbe75b66b44ec5728);
    }
    public function GetRolesForUser(int $aggregation, int $object_id, int $user_id, int $_18f48e103c59a05cbe75b66b44ec5728 = PERM_VIEW) : array
    {
        return $this->role_repository->GetRolesForUser($aggregation, $object_id, $user_id, $_18f48e103c59a05cbe75b66b44ec5728);
    }
    
    
    
    
    
    
    
    
    
    
    public function GetRightsForUser(int $aggregation, int $object_id, $user_id) : int
    {
        $_23ab4dd81b6c619f47099ef7c2485a12 = $this->role_repository->GetRoles($aggregation, $object_id);
        $_b513ed174569a7886863c416c478e44f = 0;
        foreach ($_23ab4dd81b6c619f47099ef7c2485a12 as $_d1071a032215f0eb5c4a8ef175f7049d) {
            $_1ac701da0834eb6c188cf3ef004a1aca = new \Permissions(RoleRepository::PERM_CLASS_ACL_ROLE, $_d1071a032215f0eb5c4a8ef175f7049d[$GLOBALS["__65da1b1ec2d6653e8a0ab7848e53" . "6215"]["i" . "d"]]);
            $_1ac701da0834eb6c188cf3ef004a1aca->load();
            if ($_1ac701da0834eb6c188cf3ef004a1aca->UserHasPermission(PERM_VIEW, 0, $user_id)) {
                $_b513ed174569a7886863c416c478e44f = $_b513ed174569a7886863c416c478e44f | (int) $_d1071a032215f0eb5c4a8ef175f7049d[$GLOBALS["__65da1b1ec2d6653e" . "8a0ab7848e536215"]["ri" . "gh" . "ts"]];
            }
        }
        return $_b513ed174569a7886863c416c478e44f;
    }
    
    
    
    
    
    
    
    
    
    
    public function GetObjectsForUserWithRight($aggregation, $user_id, $_18f48e103c59a05cbe75b66b44ec5728) : array
    {
        return $this->role_repository->GetObjectsForUserWithRight($aggregation, $user_id, $_18f48e103c59a05cbe75b66b44ec5728);
    }
    
    
    
    
    
    
    
    
    
    
    
    public function DoesUserHaveRight(int $aggregation, int $object_id, $user_id, $_18f48e103c59a05cbe75b66b44ec5728) : bool
    {
        $_25fb31f00b26bde87effd4759e283d9f = $this->GetRolesWithRight($aggregation, $object_id, $_18f48e103c59a05cbe75b66b44ec5728);
        if ($GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"]["_31767d7ad58e706dbf" . "47b7a51a0fe6c4"]($_25fb31f00b26bde87effd4759e283d9f) === 0) {
            return false;
        }
        $_23ab4dd81b6c619f47099ef7c2485a12 = $this->role_repository->GetRoles($aggregation, $object_id);
        $_8c6037710e6dfed74748240d3b8181f3 = [];
        foreach ($_23ab4dd81b6c619f47099ef7c2485a12 as $_d1071a032215f0eb5c4a8ef175f7049d) {
            if ($GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"]["_bd71c3b5c201fc11db82ed" . "14ce424de5"]($_d1071a032215f0eb5c4a8ef175f7049d[$GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"]["i" . "d"]], $_25fb31f00b26bde87effd4759e283d9f)) {
                $_8c6037710e6dfed74748240d3b8181f3[] = $_d1071a032215f0eb5c4a8ef175f7049d;
            }
        }
        $_99a8277755f8f533f3f5f339fcc8b45e = $this->MergeRolePerms($_8c6037710e6dfed74748240d3b8181f3);
        return $_99a8277755f8f533f3f5f339fcc8b45e->UserHasPermission(PERM_VIEW, 0, $user_id);
    }
    protected function MergeRolePerms(array $_23ab4dd81b6c619f47099ef7c2485a12) : \Permissions
    {
        $_99a8277755f8f533f3f5f339fcc8b45e = new \Permissions(RoleRepository::PERM_CLASS_ACL_ROLE);
        foreach ($_23ab4dd81b6c619f47099ef7c2485a12 as $_d1071a032215f0eb5c4a8ef175f7049d) {
            $perms = new \Permissions(RoleRepository::PERM_CLASS_ACL_ROLE, $_d1071a032215f0eb5c4a8ef175f7049d[$GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"]["i" . "d"]]);
            $perms->Load();
            $rights = $perms->GetAllPermsAsArray();
            foreach ($rights as $_49c2e3a2d006700e37253981523cf47d => $_0f0ee93b89a6a83a69ad4a5909c20cb0) {
                foreach ($_0f0ee93b89a6a83a69ad4a5909c20cb0 as $_c4d674abe9291be143b224c411958fcf => $_a606a2dcd236a549db0574a9c1675927) {
                    $_99a8277755f8f533f3f5f339fcc8b45e->Add($_a606a2dcd236a549db0574a9c1675927, $_49c2e3a2d006700e37253981523cf47d, $_c4d674abe9291be143b224c411958fcf);
                }
            }
        }
        return $_99a8277755f8f533f3f5f339fcc8b45e;
    }
}

==> claromentis-framework-9.6.5-177028fb.zip: web/intranet/core/classes/Acl/RoleBased/RoleAclChecker.php <==
<?php
namespace Claromentis\Core\Acl\RoleBased;

$GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"] = (@$GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"] ?: array()) + array("_31767d7ad58e7" . "06dbf47b7a51a0" . "fe6c4" => base64_decode("Y2" . "91" . "bn" . "Q="), "_bd71c3b5" . "c201fc11d" . "b82ed14ce" . "424de5" => base64_decode("aW5fYXJyYXk" . "="), "i" . "d" => base64_decode("a" . "W" . "Q" . "="), "rig" . "hts" => base64_decode("cmlnaH" . "Rz"));
class RoleAclChecker
{
    protected $role_repository;
    public function __construct(RoleRepository $_90f6cb30a269a622b4c838bfd5a0a5db)
    {
        $this->role_repository = $_90f6cb30a269a622b4c838bfd5a0a5db;
    }
    
    
    
    
    
    
    
    
    
    
    public function GetUsersWithRight(int $aggregation, int $object_id, int $_18f48e103c59a05cbe75b66b44ec5728) : array
    {
        $_25fb31f00b26bde87effd4759e283d9f = $this->GetRolesWithRight($aggregation, $object_id, $_18f48e103c59a05cbe75b66b44ec5728);
        if ($GLOBALS["__65da1b1ec2d6653e8a0ab7848e536" . "215"]["_31767d7ad58e706dbf47b7a" . "51a0fe6c4"]($_25fb31f00b26bde87effd4759e283d9f) === 0) {
            return [];
        }
        $_23ab4dd81b6c619f47099ef7c2485a12 = $this->role_repository->GetRoles($aggregation, $object_id);
        $_8c6037710e6dfed74748240d3b8181f3 = [];
        foreach ($_23ab4dd81b6c619f47099ef7c2485a12 as $_d1071a032215f0eb5c4a8ef175f7049d) {
            if ($GLOBALS["__65da1b1ec2d6653e8a0ab" . "7848e536215"]["_bd71c3b5c201fc11db" . "82ed14ce424de5"]($_d1071a032215f0eb5c4a8ef175f7049d[$GLOBALS["__65da1b1ec2d6653" . "e8a0ab7848e536215"]["i" . "d"]], $_25fb31f00b26bde87effd4759e283d9f)) {
                $_8c6037710e6dfed74748240d3b8181f3[] = $_d1071a032215f0eb5c4a8ef175f7049d;
            }
        }
        $_99a8277755f8f533f3f5f339fcc8b45e = $this->MergeRolePerms($_8c6037710e6dfed74748240d3b8181f3);
        return $_99a8277755f8f533f3f5f339fcc8b45e->GetIndividualsList(PERM_VIEW);
    }
    
    
    
    
    
    
    
    
    
    
    public function GetRolesWithRight(int $aggregation, int $object_id, int $_18f48e103c59a05cbe75b66b44ec5728) : array
    {
        return $this->role_repository->GetAllRolesWithRight($aggregation, $object_id, $_18f48e103c59a05cbe75b66b44ec5728);
    }
    public function GetRolesForUser(int $aggregation, int $object_id, int $user_id, int $_18f48e103c59a05cbe75b66b44ec5728 = PERM_VIEW) : array
    {
        return $this->role_repository->GetRolesForUser($aggregation, $object_id, $user_id, $_18f48e103c59a05cbe75b66b44ec5728);
    }
    
    
    
    
    
    
    
    
    
    
    public function GetRightsForUser(int $aggregation, int $object_id, $user_id) : int
    {
        $_23ab4dd81b6c619f47099ef7c2485a12 = $this->role_repository->GetRoles($aggregation, $object_id);
        $_b513ed174569a7886863c416c478e44f = 0;
        foreach ($_23ab4dd81b6c619f47099ef7c2485a12 as $_d1071a032215f0eb5c4a8ef175f7049d) {
            $_1ac701da0834eb6c188cf3ef004a1aca = new \Permissions(RoleRepository::PERM_CLASS_ACL_ROLE, $_d1071a032215f0eb5c4a8ef175f7049d[$GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"]["i" . "d"]]);
            $_1ac701da0834eb6c188cf3ef004a1aca->load();
            if ($_1ac701da0834eb6c188cf3ef004a1aca->UserHasPermission(PERM_VIEW, 0, $user_id)) {
                $_b513ed174569a7886863c416c478e44f = $_b513ed174569a7886863c416c478e44f | (int) $_d1071a032215f0eb5c4a8ef175f7049d[$GLOBALS["__65da1b1ec2" . "d6653e8a0ab7" . "848e536215"]["right" . "s"]];
            }
        }
        return $_b513ed174569a7886863c416c478e44f;
    }
    
    
    
    
    
    
    
    
    
    
    public function GetObjectsForUserWithRight($aggregation, $user_id, $_18f48e103c59a05cbe75b66b44ec5728) : array
    {
        return $this->role_repository->GetObjectsForUserWithRight($aggregation, $user_id, $_18f48e103c59a05cbe75b66b44ec5728);
    }
    
    
    
    
    
    
    
    
    
    
    
    public function DoesUserHaveRight(int $aggregation, int $object_id, $user_id, $_18f48e103c59a05cbe75b66b44ec5728) : bool
    {
        $_25fb31f00b26bde87effd4759e283d9f = $this->GetRolesWithRight($aggregation, $object_id, $_18f48e103c59a05cbe75b66b44ec5728);
        if ($GLOBALS["__65da1b1ec2d665" . "3e8a0ab7848e5362" . "15"]["_31767d7ad58e706dbf47b7a51a0" . "fe6c4"]($_25fb31f00b26bde87effd4759e283d9f) === 0) {
            return false;
        }
        $_23ab4dd81b6c619f47099ef7c2485a12 = $this->role_repository->GetRoles($aggregation, $object_id);
        $_8c6037710e6dfed74748240d3b8181f3 = [];
        foreach ($_23ab4dd81b6c619f47099ef7c2485a12 as $_d1071a032215f0eb5c4a8ef175f7049d) {
            if ($GLOBALS["__65da1b1ec2d6653e8a0ab784" . "8e536215"]["_bd71c3b5c201fc11db82ed14ce424d" . "e5"]($_d1071a032215f0eb5c4a8ef175f7049d[$GLOBALS["__65da1b1ec2d6653e" . "8a0ab7848e536215"]["i" . "d"]], $_25fb31f00b26bde87effd4759e283d9f)) {
                $_8c6037710e6dfed74748240d3b8181f3[] = $_d1071a032215f0eb5c4a8ef175f7049d;
            }
        }
        $_99a8277755f8f533f3f5f339fcc8b45e = $this->MergeRolePerms($_8c6037710e6dfed74748240d3b8181f3);
        return $_99a8277755f8f533f3f5f339fcc8b45e->UserHasPermission(PERM_VIEW, 0, $user_id);
    }
    protected function MergeRolePerms(array $_23ab4dd81b6c619f47099ef7c2485a12) : \Permissions
    {
        $_99a8277755f8f533f3f5f339fcc8b45e = new \Permissions(RoleRepository::PERM_CLASS_ACL_ROLE);
        foreach ($_23ab4dd81b6c619f47099ef7c2485a12 as $_d1071a032215f0eb5c4a8ef175f7049d) {
            $perms = new \Permissions(RoleRepository::PERM_CLASS_ACL_ROLE, $_d1071a032215f0eb5c4a8ef175f7049d[$GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"]["i" . "d"]]);
            $perms->Load();
            $rights = $perms->GetAllPermsAsArray();
            foreach ($rights as $_49c2e3a2d006700e37253981523cf47d => $_0f0ee93b89a6a83a69ad4a5909c20cb0) {
                foreach ($_0f0ee93b89a6a83a69ad4a5909c20cb0 as $_c4d674abe9291be143b224c411958fcf => $_a606a2dcd236a549db0574a9c1675927) {
                    $_99a8277755f8f533f3f5f339fcc8b45e->Add($_a606a2dcd236a549db0574a9c1675927, $_49c2e3a2d006700e37253981523cf47d, $_c4d674abe9291be143b224c411958fcf);
                }
            }
        }
        return $_99a8277755f8f533f3f5f339fcc8b45e;
    }
}
